@charset "utf-8";
/*
Title: White Lingerie
Revision: $Revision: 1.7 $
Author: Sarsya
Access: none
License: GPL
Comment: 白いランジェリーのテーマ

	Copyright (C) 2000-2001.Sarsya. All Rights Reserved. 
	Hanayashiki:http://vanilla.ath.cx/~Hanayashiki/
 */
/* ChangeLog
2002-04-05 TADA Tadashi <sho@spc.gr.jp>
	* add spec.

2002-03-15 TADA Tadashi <sho@spc.gr.jp>
	* support image anchor as span.panchor and span.canchor.
*/

/*
ページ全体の基本的な設定。背景色や文字色など
*/
body {
	background-color: #FFDECE;
	color: #FF97AD;
	background-image:url("white-lingerie_back1.gif");
	background-repeat:repeat-y;
	scrollbar-face-color: #FFDECE;
	scrollbar-highlight-color: #FFDECE;
	scrollbar-shadow-color: #FFFFFF;
	scrollbar-3dlight-color: #FFFFFF;
	scrollbar-arrow-color: #999999;
	scrollbar-track-color: #FFFFFF;
	scrollbar-darkshadow-color: #FFFFFF;
}
A:link{color:#FFC0CB}
A:visited{color:#FF99CC}
A:active{color:#9370DB}
A:link:hover { color:#DDA0DD; }

/*
ページトップにある操作ボタンの並ぶ行の設定
*/
div.adminmenu {
	text-align: right;
	font-size: small;
}

/*
ページトップにある操作ボタン自体の設定
*/
span.adminmenu {
	background-color: #FFF;
	background-image:url("white-lingerie_back2.gif");
	border-style: solid;
	border-color: #eee #ccc #ccc #eee;
	border-width: 2px;
	padding: 3px;
}

/*
日記タイトルの設定
*/
h1 {
	text-align: center;
}

/*
カレンダーの設定
*/
div.calendar {
	background-color: #FFF;
	background-image:url("white-lingerie_back2.gif");
	border-style: none;
	border-color: #FFF #FFF #FFF #FFF;
	border-width: 1px;
	padding: 1%;
	margin:1% 10% 1% 10%;
}

/*
1日の日記全体を囲む枠の設定
*/
div.day {
	background-color: #FFF;
	background-image:url("white-lingerie_back2.gif");
	border-style: none;
	border-color: #FFF #FFF #FFF #FFF;
	border-width: 1px;
	padding: 1% 1% 1% 1%;
	margin: 1% 10% 1% 10%;
}

/*
タイトル行全体の設定
*/
h2 {
	margin-top: 0.1em;
	margin-bottom: 0.1em;
}

/*
日付の設定
*/
h2 span.date {
	font-size: large;
	margin-left: 0.5em;
}

/*
タイトルの設定
*/
h2 span.title {
}

/*
タイトルを除いた1日の日記本文全体の設定
*/
div.body {
	background-color: #FFDECE;
	font-size: 100%;
	padding: 2px;
	padding-bottom: 1px;
	margin-left: 2em;
	margin-right: 2em;
}


/*
サブタイトルの設定
*/
h3 {
	font-size: 100%;
	margin: 0em;
	font-weight: bold;
}

/*
日記の本文(段落)の設定
*/
div.section p {
	margin-top: 0.5em;
	margin-bottom: 0.7em;
	line-height: 1.3;
}

/*
ツッコミ欄全体の設定
*/
div.comment {
	font-size: 100%;
	background-color: #FFDECE;
	padding: 2px;
	padding-bottom: 1px;
	margin-top: 0.5em;
	margin-left: 2em;
	margin-right: 2em;
}

/*
ツッコミ欄タイトル行の設定
*/
div.comment div.caption {
	border-style: dotted;
	border-color: #FFF;
	border-width: 0px 0px 2px 0px;
}

/*
ツッコミした人の名前の設定
*/

/*
リンク元リスト(短い方)の設定
*/
div.referer {
	text-align: right;
	font-size: small;
	background-color: #FFDECE;
	padding: 2px;
	padding-bottom: 1px;
	margin: 0.5em 2em;
}

/*
リンク元リスト(全体一覧)の設定
*/
div.refererlist {
	font-size: 80%;
	background-color: #FFDECE;
	padding: 2px;
	padding-bottom: 1px;
	margin-top: 0.5em;
	margin-left: 2em;
	margin-right: 2em;
}

/*
リンク元リストタイトルの設定
*/
div.refererlist div.caption {
	border-style: dotted;
	border-color: #FFF;
	border-width: 0px 0px 2px 0px;
}

/*
リンク元リスト一覧の設定
*/
div.refererlist ul {
	margin-top: 0em;
}

/*
罫線の設定
*/
hr {
	border-style: none;
	border-width: 2px 0px 0px 0px;
	border-color: #ddd;
}

/*
日々の日記のセパレータに使われる罫線の設定
*/
hr.sep {
	display: none;
}

/*
フッタの設定
*/
div.footer {
	font-size: 80%;
	text-align: center;
	margin-top: 0px;
}

/*
フォーム全体を囲む枠の設定
*/
div.form {
	background-color: #FFDECE;
	background-image:url("white-lingerie_back2.gif");
	padding: 0.5em 1em 0.5em 1em;
	margin: 0.5em 1em 0.5em 2em;
}

/*
入力フィールドの設定
*/
input.field {
	background-color: #FFDECE;
	color:#A461FF;
	font-size: 100%;
}

/*
複数行入力フィールドの設定
*/
textarea {
	background-color: #FFDECE;
	color:#A461FF;
	margin-left: 1em;
	width: 30em;
}

/*
エラーメッセージ表示の設定
*/
p.message {
	text-align: center;
	font-size: large;
	background-color: red;
	color: white;
	padding: 8px;
}

/*
整形済みテキスト(preタグ)の設定
*/
pre {
	background-color: #FFFFFF;
	background-image:url("white-lingerie_back2.gif");
	color: #ff8000;
	margin:1% 1% 1% 1%;
	padding:1% 1% 1% 1%;
}

/*
項目リストの設定
*/
div.body dl {
	margin-left: 2em;
}

div.body dt {
	margin-bottom: 0.2em;
	font-weight: bold;
}

div.body dd {
	margin-left: 1em;
	margin-bottom: 0.5em;
}

/*
 イメージアンカー
 */
div.day span.sanchor {
	background-image: url(white-lingerie_ppk.gif);
	background-position: bottom right;
	background-repeat: no-repeat;
	padding: 15px 15px 0px 0px;
	color: #FFDECE;
	background-color: transparent;
	font-size: 1px;
}

div.day span.canchor {
	background-image: url(white-lingerie_pppk.gif);
	background-position: bottom right;
	background-repeat: no-repeat;
	padding: 10px 10px 0px 0px;
	color: #FFDECE;
	background-color: transparent;
	font-size: 1px;
}


/*
ツッコミ省略版本文
*/
div.commentshort {
        margin-left: 0.5em;
}

span.commentator {
}

div.commentshort p {
        margin-top: 0.2em;
        margin-bottom: 0.2em;
        line-height: 1.2em;
}

/*
ツッコミ本体
*/
div.commentbody {
        margin: 0.5em;
        line-height: 1.2em;
}

/*
ツッコミした人の情報
*/
div.commentator {
        border-style: dotted;
        border-color: #FFF;
        border-width: 0px 0px 1px 0px;
        line-height: 1.5em;
	display: inline;
}

/*
ツッコミ本文
*/
div.commentbody p {
        margin: 0em;
}

/*
フォームの設定
*/
div.form form {
        margin: 0em 0em 0em 0em;
}

div.form div.caption {
        border-style: solid;
        border-color: #FFF;
        border-width: 0px 0px 1px 0px;
        margin: 0.5em;
}

div.form form.comment {
}

div.field {
        display: inline;
        margin-right: 2em;
}

form.comment input {
        background-color: #FFDECE;
        color: #A461FF;
        margin-left: 1em;
}

div.textarea {
        display: block;
        vertical-align: top;
}

form.comment textarea {
        display: block;
        background-color: #FFDECE;
        color: #A461FF;
        margin-left: 1em;
        width: 30em;
        height: 5em;
}

div.button {
        display: block;
}

/*
更新フォーム
*/
div.day.update div.form {
        margin-left: 0em;
}

form.update {
        padding-top: 0.5em;
        padding-bottom: 0.5em;
}

form.update input, form.update textarea, form.commentstat input {
        background-color: #FFDECE;
        color: #A461FF;
}

form.update span.field {
        display: inline;
        margin-left: 0em;
        margin-right: 0.5em;
}

form.update div.field.title {
        display: block;
        margin-top: 1em;
}

form.update div.field.title input {
        margin-left: 0.5em;
}

form.update div.textarea {
        display: block;
        margin-top: 1em;
}

form.update textarea {
        display: block;
        margin-left: 1em;
        margin-bottom: 1em;
        width: 35em;
        height: 15em;
}

form.update span.checkbox.hidediary {
        margin-left: 1em;
}

/*
ツッコミ状態変更フォーム
*/
div.comment form {
        margin-top: 0em;
}
