@charset "utf-8";
/*
Title: LCARS
Revision: $Revision: 1.3 $
Author: MUNEDA Takahiro
Access: mux03@panda64.net
License: GPL
Comment: STARTREK LCARS

validated by W3C.
Copyright 2005 (C) MUNEDA Takahiro <mux03@panda64.net>
*/

body {
	background-color: #000;
	color: #fff;
	margin: 0px;
	padding: 1px;
}

a:link, a:visited {
	background-color: transparent;
	color: #0A46EE;
}

a:hover {
	background-color: transparent;
	color: #4BB0FF;
}

h1 {
	margin: 10px 0px;
	padding: 0px 30px 0px 0px;
	color: #000;
	text-align: right;
	background-color: #97567B;
}

h1 a:link, h1 a:visited {
	background-color: transparent;
	color: #000;
	text-decoration: none;
}

h1 a:hover {
	background-color: transparent;
	color: #F00;
}

div.adminmenu {
	font-size: 80%;
	margin: 0.1em 10px 0px 0px;
	text-align: right;
	font-weight: bold;
	height: 20px;
}

div.adminmenu a:link, div.adminmenu a:visited {
	text-decoration: none;
	background-color: transparent;
	color: #000;
}

div.adminmenu a:hover {
	text-decoration: none;
	background-color: transparent;
	color: #FFF;
}

span.adminmenu {
	background-color: #FF9C00;
	color: #000;
	padding: 2px 6px 2px 6px;
}

div.day {
	margin: 0px;
	padding-bottom: 1em;
}

h2 {
	margin-top: 0.1em;
	margin-bottom: 0.1em;
	background-color: #FF9C00;
	color: #000;
	text-align: left;
	padding-left: 30px;
}

h2 span.date {
	font-size: medium;
	margin-left: 0.3em;
}

h2 a:link, h2 a:visited {
	text-decoration: none;
	color: #000;
}

h2 a:hover {
	text-decoration: none;
	color: #F00;
}

h2 span.title {
	font-size: large;
	margin-left: 0.3em;
	margin-right: 0.3em;
}

h2 span.nyear {
	font-size: medium;
}

div.body {
	margin: 0px;
	padding: 0px;
}

div.section {
	margin-top: 0.5em;
	margin-bottom: 0.1em;
	margin-left: 0em;
	width: 100%;
	background-image: url(lcars_orange_line.png);
	background-position: left;
	background-repeat: repeat-y;
}

h3 {
	margin: 0em;
	font-size: medium;
	font-weight: bold;
	color: #000;
	background-color: #FFFF9C;
	padding: 0.1em 0em 0.2em 1em;
	margin: 0px 0px 0px 15px;
}

h3 a {
	text-decoration: none;
}

h4 {
	padding: 0.1em 0em 0.2em 1em;
	margin: 0.5em 0px 0px 15px;
	font-size: medium;
	font-weight: bold;
}

h5 {
	margin: 2em;
	font-size: medium;
	font-weight: bold;
	margin-top: 0em;
	margin-bottom: 0em;
}

div.day span.sanchor, div.day span.canchor {
	font-size: 70%;
	margin-right: 0.5em;
	text-decoration: none;
}

div.section p {
	line-height: 150%;
	margin: 0.5em 1em 0.7em 2em;
}

div.caption {
	font-size: 90%;
	background-color: #97567B;
	padding: 0.1em 0em 0.2em 1em;
	margin: 0px 0px 0px 15px;
	color: #000;
}

div.caption a:link, div.caption a:visited, div.caption a:hover {
	text-decoration: none;
	color: #FFF;
}

div.comment {
	margin-top: 0.5em;
	margin-bottom: 0.1em;
	margin-right: 0em;
	width: 100%;
	background-image: url(lcars_orange_line.png);
	background-position: left;
	background-repeat: repeat-y;
}

div.commentshort {
	font-size: 90%;
}

div.commentator {
	margin-left: 0.3em;
}

span.commentator {
	font-weight: bold;
}

div.commentshort p {
	line-height: 120%;
	margin: 0.5em 1em 0.7em 2em;
}

div.commentbody {
	font-size: 90%;
	line-height: 120%;
	margin: 0.5em 1em 0.7em 2em;
}

div.commentbody p {
	margin-top: 0.2em;
	margin-bottom: 1em;
	margin-left: 1.5em;
}

div.form {
	margin-top: 0.5em;
	margin-bottom: 0.1em;
	margin-left: 0em;
	background-image: url(lcars_orange_line.png);
	background-position: left;
	background-repeat: repeat-y;
}

div.form form {
	margin: 0.5em 1em 0.7em 2em;
}

div.form form.comment {
	font-size: 90%;
	padding-bottom: 0.5em;
}

div.field {
	display: inline;
	margin-right: 2em;
}

form.comment input {
	background-color: #9CA8AD;
	color: #000;
	margin-left: 0.5em;
}

div.textarea {
	display: block;
	vertical-align: top;
	margin-top: 0.7em;
}

form.comment textarea {
	display: block;
	background-color: #9CA8AD;
	color: #000;
	margin-left: 3.5em;
	margin-bottom: 0.7em;
	width: 25em;
	height: 5em;
}

form.comment div.button {
	display: block;
	margin-left: 3em;
}

form.commentstat div.button {
	display: block;
	margin-left: 3em;
}

div.referer {
	text-align: right;
	font-size: 90%;
	margin: 0.5em 1em 0em 0em;
	background-image: url(lcars_orange_line.png);
	background-position: left;
	background-repeat: repeat-y;
}

div.refererlist {
	padding-bottom: 1px;
	margin: 0.5em 0em 0.5em 0em;
	background-image: url(lcars_orange_line.png);
	background-position: left;
	background-repeat: repeat-y;
}

div.refererlist ul, div.refererlist ol {
	font-size: 90%;
	line-height: 120%;
	margin: 0.5em 1em 0.7em 2em;
	padding-left: 1em;
}

div.section hr {
	border-style: dotted;
	border-color: #888;
	border-width: 1px 0px 0px 0px;
	margin-left: 4em;
	width: 70%;
}

hr.sep {
	display: none;
}

div.footer {
	font-size: 90%;
	text-align: right;
	margin-top: 1em;
	margin-right: 1em;
}

div.update {
	padding-top: 1em;
	margin: 0.5em 1em 0.7em 2em;
}

form.update {
	padding-top: 0.5em;
	padding-bottom: 0.5em;
}
form.update input, form.update textarea, form.commentstat input {
	background-color: #9CA8AD;
	color: #000;
}

form.update span.field {
	display: inline;
	margin-left: 0em;
	margin-right: 0.5em;
}

form.update div.field.title {
	display: block;
	margin-top: 1em;
}
form.update div.field.title input {
	margin-left: 0.5em;
}

form.update div.textarea {
	display: block;
	margin-top: 1em;
}
form.update textarea {
	display: block;
	margin-left: 3em;
	margin-bottom: 1em;
	width: 35em;
	height: 15em;
}

form.update span.checkbox.hidediary {
	margin-left: 1em;
}

div.comment form {
	margin-top: 0em;
}

p.message {
	text-align: center;
	font-size: large;
	background-color: #d00;
	color: #fff;
	padding: 8px;
}

div.section pre {
	background-color: #9CA8AD;
	color: #000;
	margin-left: 3em;
	margin-right: 1em;
	padding: 8px 8px 8px 8px;
}

div.section blockquote {
	margin-left: 3em;
	padding-left: 15px;
	background-image: url(lcars_lilac_line.png);
	background-position: left;
	background-repeat: repeat-y;
}
div.section blockquote p {
	margin: 0.5em 0em 0.5em 0em;
}

div.section ul, div.section ol {
	margin-left: 7em;
	margin-right: 3em;
	padding-left: 0px;
}

div.section ul ul, div.section ol ol {
	margin-left: 1.7em;
	margin-right: 1em;
	margin-bottom: 0.5em;
}

div.section dl {
	margin-left: 4em;
}

div.section dt {
	margin-bottom: 0em;
	font-weight: bold;
}

div.section dd {
	margin: 0.2em 0em 0.5em 2em;
}

div.section table {
	margin: 0.5em 1em 0.5em 5em;
	border-style: solid;
	border-width: 1px;
	border-color: #b60;
	border-collapse: collapse;
}
div.section th, div.section td {
	padding: 5px;
	border-style: solid;
	border-width: 1px;
	border-color: #b60;
}

/*
 plugins
 */
/* amazon plugin */
img.left {
	border-style: solid;
	border-color: #888;
	border-width: 1px;
	float: left;
	margin: 0.5em;
}

img.right, img.photo, img.amazon {
	border-style: solid;
	border-color: #888;
	border-width: 1px;
	float: right;
	margin: 0.5em;
}

span.blogmap {
	font-size: 80%;
}

/*
div.section, div.comment {
	clear: both;
}
*/

div.footnote {
	background-image: url(lcars_bordeaux_line.png);
	background-position: left;
	background-repeat: repeat-y;
}

div.footnote p.footnote {
	margin: 0.5em 1em 0.7em 2em;
}

div.author {
	background-image: url(lcars_bordeaux_line.png);
	background-position: left;
	background-repeat: repeat-y;
	text-align: right;
	margin: 0.5em 1em 0em 0em;
}

/*
sidebar
*/
div.main {
	margin-left: 200px;
}

div.main h4 {
	text-decoration: underline;
}

div.sidebar {
	font-size: 90%;
	position: absolute;
	top: 80px;
	left: 0px;
	width: 195px;
	padding: 4px 0px 100% 0em;
}

div.sidebar h4 {
	padding: 0.1em 0em 0.2em 0.5em;
	margin: 0em 0px 0px 0.5em;
	font-size: medium;
	font-weight: bold;
	background-color: #CD6363;
	color: #000;
	text-align: left;
}

div.sidecontents {
	margin-top: 0.5em;
	margin-bottom: 0.1em;
	margin-right: 0em;
}

div.sidecontents p {
	line-height: 120%;
	margin: 0.5em 0em 0.7em 1em;
	text-align: left;
}

div.sidecontents p.misc {
	line-height: 120%;
	margin: 0.5em 0em 0.7em 1em;
	text-align: center;
}

div.sidecontents ul, div.sidecontents ol {
	margin: 0em 0em 1em 3em;
	padding-right: 0px;
}

div.sidebar a:link,
div.sidebar a:visited,
div.sidebar a:hover,
div.footer a:link,
div.footer a:visited,
div.footer a:hover 
{
	text-decoration: none;
}

div.sidebar img {
	border: none;
}

div.calendar {
	margin: 0.5em 1em 0.7em 2em;
}

div.calendar select {
	margin-left: 8px;
}

p.recentitem {
	font-weight: bold;
	margin-left: 4px;
	margin-bottom: 0.5em;
}

div.recentsubtitles {
}

div.sidebar hr {
	border-style: solid;
	border-width: 1px 0px 0px 0px;
	border-color: #000;
	width: 80%;
}
