@charset "utf-8";
/*
        Title: Babypink
        Revision: 
        Author: epi
        Access: <http://330mg.bufferin.jp/diary/>
        License: GPL
        Comment: theme mintblueのpinkバージョン

        Copyright by epi All Rights Reserved.
       
        Modified by Nana <moo@xu.boo.jp>
        validated by W3C

--Change Log---
2002-09-13 NT <nt@24i.net>
        * convert for 1.5 series.

2002-05-16 epi
        * add leftsidebar, rightsidebar, leftmain, rightmain
                  if (sidebar == left) leftsidebar + rightmain
                  if (sidebar == right) rightsidebar +  leftmain
        * calendar2  margin modified
*/
       
/*
ページ全体の基本的な設定。背景色や文字色など
*/
body {
	color: #DB7093;
	background-color:#FFF0F5;
	font-size: 100%;
	text-align: left;
}

/* リンク */
a:link {
	text-decoration:none;
	color: #E67350;
	background-color: transparent;
}
a:visited {
	text-decoration:none;
	color: #FF9C77;
	background-color: transparent;
}
a:active, a:hover, a:focus {
	text-decoration:underline;
	color: #8b0000;
	background-color: transparent;
}

/*
ページトップにある操作ボタンの並ぶ行の設定
*/
div.adminmenu {
	text-align: right;
	font-size: 90%;
}

/*
ページトップにある操作ボタン自体の設定
*/
span.adminmenu {
	background-color: transparent;
	color: #000000;
	border-style: solid;
	border-color: #eee #BC8F8F #BC8F8F #eee;
	border-width: 1px;
	padding: 3px;
}
/*
日記タイトルの設定
*/
h1 {
	text-align: center;
}

/*
カレンダーの設定
*/
div.calendar {
	color: #FFC0CB;
	background-color: #DB7093;
	padding: 2px;
	margin-bottom: 0.5em;
}
div.calendar {
	color: #FFE4E1;
}

/*
1日の日記全体を囲む枠の設定
*/
div.day {
       margin: 0 2em 2em 2em;
}

/*
タイトル行全体の設定
*/
h2 {
	color: #DB7093;
	background-color: transparent;
	border-color: #DB7093;
	border-style:solid;
	border-width: 2px 0px 2px 0px;
	padding: 0.2em 0em;
	font-size: 100%;
}

/*
日付の設定
*/
h2 span.date {
	color: #DB7093;
	background-color: transparent;
	font-size: 120%;
	font-weight: bold;
	margin-left: 0.5em;
}
h2 span.date {
	color: #DB7093;
	background-color: transparent;
}

/*
タイトルの設定
*/
h2 span.title {
	font-size: 100%;
	font-style: normal;
	color: #FF9C77;
	background-color: transparent;
}

/*
タイトルを除いた1日の日記本文全体の設定
*/
div.body {
	color: #8b0000;
	background-color: transparent;
	padding-bottom: 1px;
}
/*
引用(blockquoteタグ)の設定
*/
div.body blockquote {
	color: #F08080;
	background-color:#FAF0E6;
	border-color:#FF9C77;
	border-style:solid;
	border-width: 1.5px 0px 1.5px 0px;
	padding: 4px;
	font-size: 90%; 
	margin: 0em 3em 0em 3em;
}

/*
サブタイトルの設定
*/
h3 {
	color: #F08080;
	background-color: transparent;
	font-style: normal;
	font-weight: normal;
	font-size: medium;
}
div.day span.sanchor {
	font-weight: bold;
}

/*
日記の本文(段落)の設定
*/
div.section {
	margin-left: 1em;
	margin-bottom: 1em;
}

div.section p {
        margin-left: 1em;
        margin-bottom: 1em;
        line-height:1.5;
}

/*
ツッコミ欄全体の設定
*/
div.comment {
	background-color: #FAF0E6;
	font-size: 90%;
	padding: 2px;
	padding-bottom: 1px;
	margin-left: 10em;
}

/*
ツッコミ欄タイトル行の設定
*/
div.comment div.caption {
	background-color: #FFE4E1;
	border-style: solid;
	border-color: #BC8F8F;
	border-width: 0px 0px 1px 0px;
	text-align: right;
}

/*
ツッコミした人の名前の設定
*/

/*
リンク元リスト(短い方)の設定
*/
div.referer {
	text-align: right;
	font-size: 90%;
	background-color: #FFE4E1;
	border-style: solid;
	border-color: #BC8F8F;
	border-width: 0px 0px 1px 0px;
	margin-left:10em;
}

/*
リンク元リスト(全体一覧)の設定
*/
div.refererlist {
	font-size: 90%;
	background-color: #FFE4E1;
	padding: 2px;
	padding-bottom: 1px;
	margin-left: 10em;
}

/*
リンク元リストタイトルの設定
*/
div.refererlist div.caption {
	border-style: solid;
	border-color: #BC8F8F;
	border-width: 0px 0px 1px 0px;
}

/*
リンク元リスト一覧の設定
*/
div.refererlist ul {
	margin-top: 0em;
}

/*
罫線の設定
*/
hr {
	border-style: solid;
	border-width: 2px 0px 0px 0px;
	border-color: #ddd;
}

/*
日々の日記のセパレータに使われる罫線の設定
*/
hr.sep {
	display: none;
}

/*
フッタの設定
*/
div.footer {
	font-size: small;
	text-align: right;
}

/*
フォーム全体を囲む枠の設定
*/
div.form {
	background-color: transparent;
	padding: 0.5em 1em 0.5em 1em;
	text-align: right;
}

/*
入力フィールドの設定
*/
input.field {
	background-color: white;
	color: #000000;
}

/*
複数行入力フィールドの設定
*/
textarea {
	background-color: white;
	color: #000000;
	margin-left: 1em;
	width: 30em;
}

/*
エラーメッセージ表示の設定
*/
p.message {
	text-align: center;
	font-size: medium;
	background-color: #FF9C77;
	color: white;
	padding: 8px;
}

/*
整形済みテキスト(preタグ)の設定
*/
pre {
	background-color: #DB7093;
	color: #8b0000;
	margin-left: 2em;
	margin-right: 1em;
	padding: 8px 8px 8px 8px;
}

/*
項目リストの設定
*/
div.body dl {
	margin-left: 2em;
}

div.body dt {
	margin-bottom: 0.2em;
}

div.body dd {
	margin-left: 1em;
	margin-bottom: 0.5em;
}

/*
 いくつかのメジャーなプラグイン対応
 */

/* calendar2 */
table.calendar {
	width:10em;
	float:right;
	font-size: small;
	line-height: 100%;
	border-width: 2px;
	border-color: #DB7093;
	border-style: solid;
	color: #FFC0CB;
	background-color: transparent;
	padding: 2px;
	padding-bottom: 1px;
	margin-top: 0.1em;
	margin-right: 4px;
	margin-left: 75%;
}

table.calendar td {
	text-align: right;
	padding: 0px;
	margin: 0px;
}

table.calendar td.calendar-prev-month, table.calendar td.calendar-current-month, table.calendar td.calendar-next-month {
	text-align: center;
}

/* recent_list */
p.recentitem {
	font-size: 90%;
	margin-top: 0px;
	margin-bottom: 0px;
}

div.recentsubtitles {
	font-size: 90%;
	margin-top: 0px;
	margin-bottom: 1em;
	margin-left: 1em;
}

/* footnote */
div.body span.footnote {
	vertical-align: super;
	font-size: xx-small;
}
div.footnote {
	border-style:solid;
	border-color: #aaa;
	border-width: 1px 0px 0px 0px;
	margin-left: 10em;
	font-size:90%;
}
div.footnote p.footnote {
	text-align: right;
	padding: 0em 0em 0em 0em;
	margin: 0em 0em 0em 0em;
}


/* 以下個人用 */

ul {
	margin: 1em 2em;
}

/* sidebar */
div.rightmain {
	margin-left: 20%;
}
div.leftmain {
	margin-right: 20%;
}

div.leftsidebar {
	background-color: transparent;
	float: left;
	width: 20%;
	height:100%;
	font-size: x-small;
	padding: 2px 2px 100% 2px;
}

div.sidebar p {
	line-height: 120%;
	text-align: center;
	margin: 2px 4px 2px 4px;
}

div.rightsidebar {
	background-color: transparent;
	float: right;
	width: 20%;
	height:100%;
	font-size: x-small;
	padding: 2px 2px 100% 2px;
}

/*
ツッコミ省略版本文
*/
div.commentshort {
        font-size: 90%;
        margin-left: 0.5em;
}

span.commentator {
        font-weight: bold;
}

div.commentshort p {
        margin-top: 0.2em;
        margin-bottom: 0.2em;
        line-height: 1.2em;
}

/*
ツッコミ本体
*/
div.commentbody {
        font-size: 90%;
        margin: 0.5em;
        line-height: 1.2em;
}

/*
ツッコミした人の情報
*/
div.commentator {
        border-style: solid;
        border-color: #BC8F8F;
        border-width: 0px 0px 1px 0px;
        line-height: 1.5em;
}

/*
ツッコミ本文
*/
div.commentbody p {
        margin: 0.5em;
        margin-left: 2em;
}

/*
フォームの設定
*/
div.form form {
        margin: 0em 0em 0em 2em;
}

div.form div.caption {
        font-size: 90%;
        border-style: solid;
        border-color: #BC8F8F;
        border-width: 0px 0px 1px 0px;
        margin: 0.5em;
}

div.form form.comment {
        font-size: 90%;
}

div.field {
        display: inline;
        margin-right: 2em;
}

form.comment input {
        background-color: white;
        color: #000000;
        margin-left: 1em;
}

div.textarea {
        display: block;
        vertical-align: top;
}

form.comment textarea {
        display: block;
        background-color: white;
        color: #000000;
        margin: 1ex 0px 1ex auto;
        width: 30em;
        height: 5em;
}

div.button {
        display: block;
        margin-left: 3em;
}

/*
更新フォーム
*/
form.update {
        padding-top: 0.5em;
        padding-bottom: 0.5em;
}

form.update input, form.update textarea, form.commentstat input {
        background-color: white;
        color: #000000;
}

form.update span.field {
        display: inline;
        margin-left: 0em;
        margin-right: 0.5em;
}

form.update div.field.title {
        display: block;
        margin-top: 1em;
}

form.update div.field.title input {
        margin-left: 0.5em;
}

form.update div.textarea {
        display: block;
        margin-top: 1em;
}

form.update textarea {
        display: block;
        margin: 1ex 0px 1ex auto;
        width: 35em;
        height: 15em;
}

form.update span.checkbox.hidediary {
        margin-left: 1em;
}

/*
ツッコミ状態変更フォーム
*/
div.comment form {
        margin-top: 0em;
}
